==> haskell-hasql-1.1.1-87-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hasql.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql
version: 1.1.1
id: hasql-1.1.1-8DJGU8QBHVQJLpEFQQC1sO
key: hasql-1.1.1-8DJGU8QBHVQJLpEFQQC1sO
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql
synopsis: An efficient PostgreSQL driver and a flexible mapping API
description:
    This package is the root of the \"hasql\" ecosystem.
    .
    The API is completely disinfected from exceptions. All error-reporting is explicit and is presented using the '\''Either'\'' type.
    .
    The version 1 is completely backward-compatible with 0.19.
category: Hasql, Database, PostgreSQL
abi: fb303a9f43c702a7c23992a5bb286853
exposed: True
exposed-modules:
    Hasql.Connection Hasql.Decoders Hasql.Encoders Hasql.Query
    Hasql.Session
hidden-modules: Hasql.Private.Prelude Hasql.Private.PTI
                Hasql.Private.IO Hasql.Private.Query Hasql.Private.Session
                Hasql.Private.Connection Hasql.Private.PreparedStatementRegistry
                Hasql.Private.Settings Hasql.Private.Commands
                Hasql.Private.Decoders.Array Hasql.Private.Decoders.Composite
                Hasql.Private.Decoders.Value Hasql.Private.Decoders.Row
                Hasql.Private.Decoders.Result Hasql.Private.Decoders.Results
                Hasql.Private.Encoders.Array Hasql.Private.Encoders.Value
                Hasql.Private.Encoders.Params
import-dirs: /usr/lib/ghc-8.4.3/site-local/hasql-1.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/hasql-1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hasql-1.1.1
hs-libraries: HShasql-1.1.1-8DJGU8QBHVQJLpEFQQC1sO
depends:
    attoparsec-0.13.2.2-3UshHsIb0S9BZJuxZmJPoQ
    postgresql-binary-0.12.1.1-2fspbi3XT4g8ce7QCaOit2
    postgresql-libpq-0.9.4.1-HmQUg7WTong1815HjPkViU
    bytestring-strict-builder-0.4.5.1-9Vnr8Il7aBn7qCbqB53wDK
    dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    hashtables-1.2.3.1-FwvkrjNnnglEJJXpMCqokg text-1.2.3.0
    bytestring-0.10.8.2 hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    profunctors-5.2.2-IakD9ZOOFJRiYSnH5jCC9
    contravariant-extras-0.3.4-JCQKBj7kvwO5L5p7jVngui
    contravariant-1.4.1-HAsNOXS6UjNLhhUqovtoIr mtl-2.2.2
    transformers-0.5.5.0 loch-th-0.2.2-5Eq2dK8L8YJJWK4HNR9w70
    placeholders-0.1-4bE0Visrk2tFnTI1hMfyUR
    base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7 base-4.11.1.0
abi-depends: attoparsec-0.13.2.2-3UshHsIb0S9BZJuxZmJPoQ=b6c55238d5ca948928baa2c3b9c37177
             postgresql-binary-0.12.1.1-2fspbi3XT4g8ce7QCaOit2=b7f9f95ffce5ba9c7be7f8d46442c092
             postgresql-libpq-0.9.4.1-HmQUg7WTong1815HjPkViU=7cd7fa6df4228acf82fa6488bd789ef0
             bytestring-strict-builder-0.4.5.1-9Vnr8Il7aBn7qCbqB53wDK=0bd6b90a893f0a1d3227a5eff0aef4ce
             dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD=f79b3ead594e04b4f22b6b2afc0a8656
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             hashtables-1.2.3.1-FwvkrjNnnglEJJXpMCqokg=9716e82ce2a1119e069e6c69de7a6cc9
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=82e1626338bbe81f5b3354a12d7a2c38
             profunctors-5.2.2-IakD9ZOOFJRiYSnH5jCC9=1d508abbc1f63249e29622eb3e284eb1
             contravariant-extras-0.3.4-JCQKBj7kvwO5L5p7jVngui=58b93e15034d8eff836872339341af39
             contravariant-1.4.1-HAsNOXS6UjNLhhUqovtoIr=c99faff75f3a482d24cfc7bf782693a7
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             loch-th-0.2.2-5Eq2dK8L8YJJWK4HNR9w70=00fd0dc72b72ed83b5d37907b4600d8e
             placeholders-0.1-4bE0Visrk2tFnTI1hMfyUR=c1d872831901a2463250620e0e797580
             base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7=6440a7e70ad5450b51ffd7c9c4277ed3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-hasql/html/hasql.haddock
haddock-html: /usr/share/doc/haskell-hasql/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-1.1.1-111-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hasql.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql
version: 1.1.1
id: hasql-1.1.1-AuW1ao1Fr1g15LzBnPNAHd
key: hasql-1.1.1-AuW1ao1Fr1g15LzBnPNAHd
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql
synopsis: An efficient PostgreSQL driver and a flexible mapping API
description:
    This package is the root of the \"hasql\" ecosystem.
    .
    The API is completely disinfected from exceptions. All error-reporting is explicit and is presented using the '\''Either'\'' type.
    .
    The version 1 is completely backward-compatible with 0.19.
category: Hasql, Database, PostgreSQL
abi: 093a7cb1161403dedf7574b117b8809d
exposed: True
exposed-modules:
    Hasql.Connection Hasql.Decoders Hasql.Encoders Hasql.Query
    Hasql.Session
hidden-modules: Hasql.Private.Prelude Hasql.Private.PTI
                Hasql.Private.IO Hasql.Private.Query Hasql.Private.Session
                Hasql.Private.Connection Hasql.Private.PreparedStatementRegistry
                Hasql.Private.Settings Hasql.Private.Commands
                Hasql.Private.Decoders.Array Hasql.Private.Decoders.Composite
                Hasql.Private.Decoders.Value Hasql.Private.Decoders.Row
                Hasql.Private.Decoders.Result Hasql.Private.Decoders.Results
                Hasql.Private.Encoders.Array Hasql.Private.Encoders.Value
                Hasql.Private.Encoders.Params
import-dirs: /usr/lib/ghc-8.4.3/site-local/hasql-1.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/hasql-1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hasql-1.1.1
hs-libraries: HShasql-1.1.1-AuW1ao1Fr1g15LzBnPNAHd
depends:
    attoparsec-0.13.2.2-5oKqcFqqk8HLoRElqn64fK
    postgresql-binary-0.12.1.1-2QBdiSfSukxDFM4q6EyBKu
    postgresql-libpq-0.9.4.1-HmQUg7WTong1815HjPkViU
    bytestring-strict-builder-0.4.5.1-7W6ZTyQAHwiLmjkaniZx6g
    dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    hashtables-1.2.3.1-FwvkrjNnnglEJJXpMCqokg text-1.2.3.0
    bytestring-0.10.8.2 hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    profunctors-5.3-9FfinDuGLWFA0z8WCPFmPD
    contravariant-extras-0.3.4-G0FtwWS1Rt48QPt2Rs62my
    contravariant-1.5-HWHOmzUIRDZBjbL8Fw1HTI mtl-2.2.2
    transformers-0.5.5.0 loch-th-0.2.2-5Eq2dK8L8YJJWK4HNR9w70
    placeholders-0.1-4bE0Visrk2tFnTI1hMfyUR
    base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7 base-4.11.1.0
abi-depends: attoparsec-0.13.2.2-5oKqcFqqk8HLoRElqn64fK=fff7ae21f45c1b0af12007963cebbf81
             postgresql-binary-0.12.1.1-2QBdiSfSukxDFM4q6EyBKu=e017698e859c0892fb2f33d6d5be260c
             postgresql-libpq-0.9.4.1-HmQUg7WTong1815HjPkViU=7cd7fa6df4228acf82fa6488bd789ef0
             bytestring-strict-builder-0.4.5.1-7W6ZTyQAHwiLmjkaniZx6g=8767cdc8b2d8ae85e00fb8924996fd13
             dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD=f79b3ead594e04b4f22b6b2afc0a8656
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             hashtables-1.2.3.1-FwvkrjNnnglEJJXpMCqokg=9716e82ce2a1119e069e6c69de7a6cc9
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=82e1626338bbe81f5b3354a12d7a2c38
             profunctors-5.3-9FfinDuGLWFA0z8WCPFmPD=c4f5caccd7270609435ed7e692ca0cda
             contravariant-extras-0.3.4-G0FtwWS1Rt48QPt2Rs62my=26f92f5a16f6701659c713c1cffd1422
             contravariant-1.5-HWHOmzUIRDZBjbL8Fw1HTI=d2f13618f92bbccf0540968a185d3c43
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             loch-th-0.2.2-5Eq2dK8L8YJJWK4HNR9w70=00fd0dc72b72ed83b5d37907b4600d8e
             placeholders-0.1-4bE0Visrk2tFnTI1hMfyUR=c1d872831901a2463250620e0e797580
             base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7=6440a7e70ad5450b51ffd7c9c4277ed3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-hasql/html/hasql.haddock
haddock-html: /usr/share/doc/haskell-hasql/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
